datastructuretools.OrdinalConstant
==================================

.. abjad-lineage:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant

.. autoclass:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__eq__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__ge__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__gt__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__le__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__lt__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__ne__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant.OrdinalConstant.__repr__
   :noindex:
